﻿define("epi-ecf-ui/component/viewmodel/CatalogsViewModel", [
// dojo
    "dojo/_base/array",
    "dojo/_base/declare",
    "dojo/_base/lang",
    "dojo/when",
// epi
    "epi-cms/asset/view-model/HierarchicalListViewModel",
// Commerce
    "../../command/NavigateToEditPage",
    "../../command/ShowCatalogThumbnails",
    "../../widget/viewmodel/CatalogTreeStoreModel"
],

function (
// dojo
    array,
    declare,
    lang,
    when,
// epi
    HierarchicalListViewModel,
// Commerce
    NavigateToEditPageCommand,
    ShowCatalogThumbnailsCommand,
    CatalogTreeStoreModel
) {
    // module:
    //      epi-ecf-ui.component.viewmodel.CatalogsViewModel

    return declare([HierarchicalListViewModel], {
        // summary:
        //      Catalogs view model.
        // tags:
        //      public

        treeStoreModelClass: CatalogTreeStoreModel,

        // showCatalogThumbnails: [public] Boolean
        //      Flag which indicates whether to show thumbnails in catalog hierarchical list. Value is true if thumbnails should be shown; otherwise false.
        showCatalogThumbnails: true,

        postscript: function () {
            this.inherited(arguments);

            this.set("commands", [new ShowCatalogThumbnailsCommand({ model: this })]);
        },

        startup: function () {
            this.inherited(arguments);

            // if navigateOnEdit is true, let's replace the edit command to NavigateToEditPageCommand
            // so when editing the content, the browser will navigate to edit page instead of changing context.
            if (this.get("navigateOnEdit")) {
                this._commandRegistry.edit.command = new NavigateToEditPageCommand({ category: "context" });
            }
        },

        destroy: function () {
            this.inherited(arguments);

            this.get("treeStoreModel").destroy();
        },

        _showCatalogThumbnailsSetter: function (value) {
            // summary:
            //      Set the show catalog thumbnails property.
            // tags:
            //      protected

            this.showCatalogThumbnails = value;
        },

        contentContextChanged: function (context, callerData) {
            // summary:
            //      Called when the currently loaded content changes. I.e. a new content data object is loaded into the preview area.
            //      Override _ContextContextMixin.contentContextChanged
            // tags:
            //      protected override

            // If the list already has a context, don't change it
            var oldListRef = this.get("currentListItem");
            if (oldListRef) {
                return;
            }

            if (this.selectedListItems && this.selectedListItems.length > 0 && this.selectedListItems[0].parentLink === context.parentLink) {
                return;
            }

            // If not, let the base implementation set up the initial context
            this.inherited(arguments);
        },

        _createListChildrenQuery: function (items) {
            // summary:
            //      Creates a new query .
            // tags:
            //      private

            // remove all mainNavigationTypes from containedTypes, to avoid of displaying Folder in Content List
            this.inherited(arguments);
            var contentTypes = array.filter(this.containedTypes, function (item) {
                return this.mainNavigationTypes.indexOf(item) < 0;
            }, this);

            var ids = items.map(function (item) {
                return item.contentLink.toString();
            });

            var marketingId = '';
            if (this._currentContext.dataType.includes('marketing')) {
                marketingId = this._currentContext.id;
            }

            if (marketingId !== '') {
                return { references: ids, query: "getpagedchildren", allLanguages: this.showAllLanguages, typeIdentifiers: contentTypes, marketingId: marketingId };
            }
            return { references: ids, query: "getpagedchildren", allLanguages: this.showAllLanguages, typeIdentifiers: contentTypes };
        },

        _createListSearchQuery: function (searchText) {
            this.inherited(arguments);
            var marketingId = '';
            if (this._currentContext.dataType.includes('marketing')) {
                marketingId = this._currentContext.id;
            }

            if (marketingId !== '') {
                return {
                    queryText: searchText,
                    query: "searchentries",
                    allLanguages: this.showAllLanguages,
                    contentSearchAreas: this.get("searchArea"),
                    searchRoots: this.get("searchRoots"),
                    maxResults: 1000,
                    filterDeleted: true,
                    marketingId: marketingId
                };
            }
            return {
                queryText: searchText,
                query: "searchcontent",
                allLanguages: this.showAllLanguages,
                contentSearchAreas: this.get("searchArea"),
                searchRoots: this.get("searchRoots"),
                maxResults: 1000,
                filterDeleted: true
            };
        },

        _listQuerySetter: function (value) {
            // summary:
            //      Custom setter for the list query to create a different query depending
            //      on if the item supports sorting of children.
            // tags:
            //      private

            if (!value) {
                this.listQuery = value;
                return;
            }
        }
    });
});